module Pages.Dodgers exposing (Model, Msg, page)

import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Effect exposing (Effect)
import Element exposing (..)
import Element.Border as D
import Element.Font as F
import Html.Attributes as H exposing (style)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Model -> View Msg
view model =
    { title = dodgersName
    , attributes = []
    , element = dodgersContainer
    }


dodgersContainer : Element msg
dodgersContainer =
    topLevelContainer dodgersList


dodgersList : Element msg
dodgersList =
    column
        pageList
        dodgers


type alias MakeRowInput msg =
    { cuckImage : String
    , cuckName : String
    , cuckSocial : String
    , cuckDodges : List (DodgeEntry msg)
    }


type alias DodgeEntry msg =
    { dodgeLink : String
    , dodgeDescription : String
    , dodgeProposition : String
    , dodgeNicksPosition : Element msg
    }


makeRow : MakeRowInput msg -> Element msg
makeRow makeRowInput =
    let
        cuckImageFormat : List (Attribute msg)
        cuckImageFormat =
            [ centerX, centerY, D.rounded 100, clip, width <| px 80 ]

        dodgeRows : List (Element msg)
        dodgeRows =
            List.indexedMap
                (\index dodgeEntry ->
                    column paragraphAlignLeft
                        [ row paragraphFormat
                            [ text "    "
                            , text (String.fromInt (index + 1) ++ ". ")
                            , paragraphLinkFormat
                                { url = dodgeEntry.dodgeLink
                                , label =
                                    row []
                                        [ transitionHighlightedLinkHover <| text dodgeEntry.dodgeDescription
                                        , text "." |> el [ F.color colourTheme.nonHighlightedText ]
                                        ]
                                }
                            ]
                        , row paragraphBoldFormat
                            [ text "                Proposition:"
                            , row [ F.regular ]
                                [ text dodgeEntry.dodgeProposition ]
                            ]
                        , row paragraphBoldFormat
                            [ text "                Doxastic State:"
                            , row [ F.regular ] [ dodgeEntry.dodgeNicksPosition ]
                            ]
                        ]
                )
                makeRowInput.cuckDodges
    in
    row [ imageSpacer, alignLeft ]
        [ image cuckImageFormat
            { src = makeRowInput.cuckImage
            , description = makeRowInput.cuckName
            }
        , column
            paragraphAlignLeft
            [ row nonHighlightedTitleFormat [ text makeRowInput.cuckName ]
            , row paragraphBoldFormat
                [ text "Social:"
                , paragraphLinkFormat
                    { url = makeRowInput.cuckSocial
                    , label = transitionHighlightedLinkHover <| text makeRowInput.cuckName
                    }
                ]
            , row paragraphBoldFormat [ text "Dodges:" ]
            , column [ spacing 8 ] dodgeRows
            ]
        ]


type alias DodgeType =
    { noReply : String
    , ranAway : String
    , ghostedMe : String
    , outrightNo : String
    , inTooDeep : String
    , killScreen : String
    }


type alias PropType =
    { noClearProp : String
    }


type alias DoxasticType msg =
    { trueState : Element msg
    , falseState : Element msg
    , agnosticState : Element msg
    , unevalState : Element msg
    , vagueState : Element msg
    }


dodgers : List (Element msg)
dodgers =
    let
        dodgeType : DodgeType
        dodgeType =
            { noReply = "Invitation extended with no response"
            , ranAway = "Engaged in written debate and dodged when cornered"
            , ghostedMe = "Debate invitation accepted with no follow-up"
            , outrightNo = "Debate invitation declined"
            , inTooDeep = "Debate invitation accepted and subsequently retracted"
            , killScreen = "All further debate invitations preemptively declined"
            }

        propType : PropType
        propType =
            { noClearProp = "failed to state position clearly."
            }

        doxasticType : DoxasticType msg
        doxasticType =
            { trueState =
                row []
                    [ text "Nick leans more toward "
                    , text "TRUE" |> el [ F.bold ]
                    , text " than false."
                    ]
            , falseState =
                row []
                    [ text "Nick leans more toward "
                    , text "FALSE" |> el [ F.bold ]
                    , text " than true."
                    ]
            , agnosticState = text "Nick doesn't form beliefs about this proposition."
            , unevalState = text "there is no proposition to evaluate."
            , vagueState = text "the proposition is too vague to evaluate."
            }
    in
    List.map makeRow
        [ { cuckImage = "cucks/adamsinger.png"
          , cuckName = "Adam Singer"
          , cuckSocial = "https://twitter.com/AdamSinger"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1566491269194719232?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/annchilders.png"
          , cuckName = "Ann Childers"
          , cuckSocial = "https://twitter.com/AnnChildersMD"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1447245484356108292?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"diets humans thrived on in the wild, sans dentists and doctors, are correct.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/anthonygustin.png"
          , cuckName = "Anthony Gustin"
          , cuckSocial = "https://twitter.com/dranthonygustin"
          , cuckDodges =
                [ { dodgeLink = ""
                  , dodgeDescription = dodgeType.ghostedMe
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/ashwanigarg.png"
          , cuckName = "Ashwani Garg"
          , cuckSocial = "https://twitter.com/agargmd"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1443328350982967303?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"representing the protein content of beans by dry weight is misleading.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/austinherbert.png"
          , cuckName = "Austin Herbert"
          , cuckSocial = "https://x.com/_AustinHerbert"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1663698981833277440"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                ]
          }
        , { cuckImage = "cucks/bartkay.png"
          , cuckName = "Bart Kay"
          , cuckSocial = "https://twitter.com/@Bart_WT_Kay"
          , cuckDodges =
                [ { dodgeLink = "https://www.youtube.com/watch?v=M7vTJ02xxrw"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"a 100% Carnivore diet is the appropriate and best health choice for all people.\""
                  , dodgeNicksPosition = doxasticType.vagueState
                  }
                ]
          }
        , { cuckImage = "cucks/benbikman.png"
          , cuckName = "Ben Bikman"
          , cuckSocial = "https://twitter.com/BenBikmanPhD"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1587547250074746880?s=19"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"the diet-heart hypothesis is false.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/bennymalone.png"
          , cuckName = "Benny Malone"
          , cuckSocial = "https://twitter.com/bennymaloneUK"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1530933999610171392?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"eating oysters is compatible with veganism.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/bradcampbell.png"
          , cuckName = "Brad Campbell"
          , cuckSocial = "https://twitter.com/DrBradCampbell"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1530933999610171392?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"canola oil kills you slowly.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/bradcohn.png"
          , cuckName = "Brad Cohn"
          , cuckSocial = "https://x.com/BradCohn"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1687535030862831616"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are not a significant, independent concern for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/bradmarshall.png"
          , cuckName = "Brad Marshall"
          , cuckSocial = "https://x.com/fire_bottle"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1669350936651911173"
                  , dodgeDescription = dodgeType.inTooDeep
                  , dodgeProposition = "\"being vegan is impossible.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/briankerley.png"
          , cuckName = "Brian Kerley"
          , cuckSocial = "https://twitter.com/SeedOilDsrspctr"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1483889771134926849?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1783200352646619227"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/carnivoreaurelius.png"
          , cuckName = "Carnivore Aurelius"
          , cuckSocial = "https://twitter.com/AlpacaAurelius"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1538272143061815299?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"vegans kill 100x more animals.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/cateshanahan.png"
          , cuckName = "Cate Shanahan"
          , cuckSocial = "https://twitter.com/drcateshanahan"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1266438463634632709?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are pro-inflammatory.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1479497980570857474?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"those who defend seed oils are just regurgitating the garbage that the AHA pumps out.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1487215337116508162?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are toxic.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/drcateshanahan/status/1516904406805057537?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"current levels of seed oil consumption are the main driver of the obesity and chronic disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1537544882532716544?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"Nick is just following the AHA marching orders.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1778616438116483102"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1779185488521310601"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1778616438116483102"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1798766450255253987"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"current levels of seed oil consumption are the main driver of heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/chrisboettcher.png"
          , cuckName = "Chris Boettcher"
          , cuckSocial = "https://x.com/chrisboettcher9"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/MeggGawat/status/1669691841682210822"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are making you fat, depressed, and sick.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/claraaboel.png"
          , cuckName = "Clara Aboel"
          , cuckSocial = "https://x.com/AIWellnessCoach"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1727510906655969736"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"polyunsaturated fatty acids are known to initiate cancer.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/clemenszsofia.png"
          , cuckName = "Clemens Zsófia"
          , cuckSocial = "https://twitter.com/ClemensZsofia"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1528377198180290561?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                ]
          }
        , { cuckImage = "cucks/cliffharvey.png"
          , cuckName = "Cliff Harvey"
          , cuckSocial = "https://twitter.com/CarbAppropriate"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/CarbAppropriate/status/1372281626206507010?s=20"
                  , dodgeDescription = dodgeType.inTooDeep
                  , dodgeProposition = "\"saturated fat in the diet does not independently increase the risk of mortality.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1500650543886204929?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"saturated fat in the diet does not independently increase the risk of mortality.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/davefeldman.png"
          , cuckName = "Dave Feldman"
          , cuckSocial = "https://twitter.com/realDaveFeldman"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1306625219440730118?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                ]
          }
        , { cuckImage = "cucks/daviddiamond.png"
          , cuckName = "David Diamond"
          , cuckSocial = "https://twitter.com/LDLSkeptic"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/LDLSkeptic/status/1583471298306375681?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"statin therapy is not warranted for a person high LDL-C on a low-carb diet.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/LDLSkeptic/status/1583481964840902656?s=20"
                  , dodgeDescription = dodgeType.killScreen
                  , dodgeProposition = "\"statin therapy is not warranted for a person high LDL-C on a low-carb diet.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/davidgornoski.png"
          , cuckName = "David Gornoski"
          , cuckSocial = "https://twitter.com/DavidGornoski"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1525474063044550657?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"polyunsaturated fatty acids cause obesity.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/dianarodgers.png"
          , cuckName = "Diana Rodgers"
          , cuckSocial = "https://twitter.com/sustainabledish"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1365857401786814465?s=20"
                  , dodgeDescription = dodgeType.inTooDeep
                  , dodgeProposition = "\"saturated fat doesn't increase the risk of coronary heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/edwardgoeke.png"
          , cuckName = "Edward Goeke"
          , cuckSocial = "https://twitter.com/GoekeEddie"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1773421625150746784?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are inflammatory.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1774154640403423359?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are inflammatory.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/eliejarrouge.png"
          , cuckName = "Elie Jarrouge"
          , cuckSocial = "https://twitter.com/ElieJarrougeMD"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1506845469980315648?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"sugar, refined carbs, and seed oils are poison.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/garybrecka.png"
          , cuckName = "Gary Brecka"
          , cuckSocial = "https://twitter.com/garybrecka1"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1726664526316372125"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"linoleic acid consumption causes atherosclerosis.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/garyfettke.png"
          , cuckName = "Gary Fettke"
          , cuckSocial = "https://x.com/FructoseNo"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1460983496524980224"
                  , dodgeDescription = dodgeType.ghostedMe
                  , dodgeProposition = "\"at current Western levels of intake, dietary linoleic acid is not a significant, independent concern for the development of chronic diseases.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/garytaubes.png"
          , cuckName = "Gary Taubes"
          , cuckSocial = "https://twitter.com/garytaubes"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/garytaubes/status/1595180467552018432?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"carbohydrates cause starvation.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/georgemartin.png"
          , cuckName = "George Martin"
          , cuckSocial = "https://x.com/CarnismDebunked"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1815098730141651021"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"Nick has killed more animals in his life than a mature bear.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/guyaustin.png"
          , cuckName = "Guy Austin"
          , cuckSocial = "https://x.com/GuyNAustin"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1538607434176020480"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://x.com/GuyNAustin/status/1687530045101744128"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"seed oils are not a significant, independent concern for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/ivorcummins.png"
          , cuckName = "Ivor Cummins"
          , cuckSocial = "https://twitter.com/FatEmperor"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1268600451693494273?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"LDL does not cause coronary heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/FatEmperor/status/1636920650156724226?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"LDL does not cause coronary heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/jakemey.png"
          , cuckName = "Jake Mey"
          , cuckSocial = "https://twitter.com/CakeNutrition"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1490009495581298690?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"Vegan Friday meals are unhealthy for children.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1490060813138280450?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"Vegan Friday meals are unhealthy for children.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1495419256737091585?s=20"
                  , dodgeDescription = dodgeType.killScreen
                  , dodgeProposition = "\"Vegan Friday meals are unhealthy for children.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/jamesdinicolantonio.png"
          , cuckName = "James DiNicolantonio"
          , cuckSocial = "https://twitter.com/drjamesdinic"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1460788569388171268?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"dietary linoleic acid is not a significant, independent concern for the development of chronic diseases.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/justinmares.png"
          , cuckName = "Justin Mares"
          , cuckSocial = "https://twitter.com/jwmares"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1329266554089869312?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"vegetable oils drive inflammation and are causally linked to weight gain and diseases of inflammation.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/josepheverett.png"
          , cuckName = "Joseph Everett"
          , cuckSocial = "https://twitter.com/JEverettLearned"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1535334822825971712?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils cause coronary heart disease and cancer.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1555138038740680704?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils cause coronary heart disease and cancer.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/kaitmalthaner.png"
          , cuckName = "Kait Malthaner"
          , cuckSocial = "https://twitter.com/healthcoachkait"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1503258756687306753?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"omega-6 is pro-inflammatory.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/kemminnick.png"
          , cuckName = "Kem Minnick"
          , cuckSocial = "https://twitter.com/kemminnick"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/kemminnick/status/1469336100300726273?s=20"
                  , dodgeDescription = dodgeType.ghostedMe
                  , dodgeProposition = "\"seed oils are not a significant, independent concern for the development of chronic diseases.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1476990862793986052?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"seed oils are not a significant, independent concern for the development of chronic diseases.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/kenberry.png"
          , cuckName = "Ken Berry"
          , cuckSocial = "https://twitter.com/KenDBerryMD"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1366524889067368449?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"type 2 diabetes is chronic carbohydrate overdose.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1539720236701589504?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"replacing animal fats with vegetable oils is dangerous.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1539721408372039680?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"replacing animal fats with vegetable oils is dangerous.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1813969807521300615"
                  , dodgeDescription = dodgeType.inTooDeep
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                ]
          }
        , { cuckImage = "cucks/kevinstock.png"
          , cuckName = "Kevin Stock"
          , cuckSocial = "https://twitter.com/kevinstock12"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1530140722225102848?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1534927799911317509?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"saturated fat does not cause cardiovascular disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/kylemamounis.png"
          , cuckName = "Kyle Mamounis"
          , cuckSocial = "https://twitter.com/Nutricrinology"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1389259133044477953?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"statins do not prevent cardiovascular events.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/marksisson.png"
          , cuckName = "Mark Sisson"
          , cuckSocial = "https://twitter.com/Mark_Sisson"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1488360227141419009?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                ]
          }
        , { cuckImage = "cucks/martykendall.png"
          , cuckName = "Marty Kendall"
          , cuckSocial = "https://twitter.com/martykendall2"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1310548994804809729"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"to access your body fat, you need to deplete both glucose and fat from the blood first.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/maxlugavere.png"
          , cuckName = "Max Lugavere"
          , cuckSocial = "https://twitter.com/maxlugavere"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/maxlugavere/status/1517683567249149953?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"seed oils consumption is associated with an increased risk of CVD and Alzheimer's disease.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1518307089742848000?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils consumption is associated with an increased risk of CVD and Alzheimer's disease.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/maxlugavere/status/1518367365683064833?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"seed oils consumption is associated with an increased risk of CVD and Alzheimer's disease.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/michaelkummer.png"
          , cuckName = "Michael Kummer"
          , cuckSocial = "https://twitter.com/mkummer82"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/mkummer82/status/1465755847917715464?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"polyunsaturated fats cause cell damage, inflammation and metabolic dysfunction.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/michaelmanderville.png"
          , cuckName = "Michael Manderville"
          , cuckSocial = "https://twitter.com/MikeManderville"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1503036463306489856?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"a logically coherent position will have logically coherent answer to a logically coherent hypothetical.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/mike mutzel.png"
          , cuckName = "Mike Mutzel"
          , cuckSocial = "https://twitter.com/MikeMutzel"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1414457776982552576?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"COVID is nothing more than a cold to those that are healthy.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1584645853771616256?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"there is little to no association between saturated fat and cardiovascular disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/mikesweeney.png"
          , cuckName = "Mike Sweeney"
          , cuckSocial = "https://twitter.com/thelowcarb_rd"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1746962254052962552"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"vegan diets are nowhere near appropriate for the average person in society.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://x.com/thelowcarb_rd/status/1654182805964836865"
                  , dodgeDescription = dodgeType.ghostedMe
                  , dodgeProposition = "\"statistical gymnastics don't inform on real world mechanisms and hard outcomes.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1776652108646821913?t=Pf4sfAC1Z0pAcxGfQFr7oQ"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"Cheerios cause nausea, vomiting, seizures, irregular heartbeat, liver damage, and coma.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/nickeggleton.png"
          , cuckName = "Nick Eggleton"
          , cuckSocial = "https://twitter.com/NickEggleton"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1266626885703720961?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"polyunsaturated fats are poison.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/ninateicholz.png"
          , cuckName = "Nina Teicholz"
          , cuckSocial = "https://twitter.com/bigfatsurprise"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1556510529014882305?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"the science linking red meat to heart disease is very weak.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1467571763865210881?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"the available evidence supports limiting saturated fat intake for coronary heart disease risk reduction.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1538895943050878977?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"vegans pretend biology isn't real.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/norstrongchris.png"
          , cuckName = "Norstrong Chris"
          , cuckSocial = "https://twitter.com/NNMChris"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/NorstrongHealth/status/1416939281973530626?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"government funded USDA data is untrustworthy.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1534573919562350594?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"nutrition science as a whole is shit.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1534614710196260865?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"nutrition science as a whole is shit.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/paulmason.png"
          , cuckName = "Paul Mason"
          , cuckSocial = "https://twitter.com/DrPaulMason"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/Tom_Babington1/status/1361644276866830337?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                , { dodgeLink = "https://twitter.com/IdanOnTweeter/status/1373233980594618371?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"Ancel Keys' Seven Countries Study was flawed.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1461361726943760391?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"dietary linoleic acid is not a significant, independent concern for the development of chronic diseases.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/paulsaladino.png"
          , cuckName = "Paul Saladino"
          , cuckSocial = "https://twitter.com/paulsaladinomd"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1275912849999695872?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"subsidies for corn and soy are huge contributors to the chronic disease epidemic in the US.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/FoodFirst_Ty/status/1282847039596843009?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://twitter.com/FoodFirst_Ty/status/1283449495682904064?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"to exclude animal foods from the human diet is a nutritional catastrophe.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1282851963902636032?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"to exclude animal foods from the human diet is a nutritional catastrophe.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1469136550046814219?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"nutritional epidemiology generally provides good causal estimates.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1633831762509045766?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"linoleic acid wreaks havoc in your body.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/philipovadia.png"
          , cuckName = "Philip Ovadia"
          , cuckSocial = "https://twitter.com/ifixhearts"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1557791520324890624?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"sugar is the problem and meat is the solution.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                , { dodgeLink = "https://twitter.com/TheNutrivore/status/1558282337024180224?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"LDL doesn't cause coronary heart disease because it is just part of the arterial repair process.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/philippestephenson.png"
          , cuckName = "Philippe Stephenson"
          , cuckSocial = "https://twitter.com/TotalCytopath"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1779587012120715433"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils save lives.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/ralphnapolitano.png"
          , cuckName = "Ralph Napolitano"
          , cuckSocial = "https://twitter.com/DrRalphNap"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1462794580848300034?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"oatmeal is one of the worst foods you can eat and has no health benefits.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/raphaelsirtoli.png"
          , cuckName = "Raphael Sirtoli"
          , cuckSocial = "https://twitter.com/raphaels7"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/raphaels7/status/1475767357188579329?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"the diet-heart hypothesis is false.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://x.com/raphaels7/status/1783541746015654072"
                  , dodgeDescription = dodgeType.killScreen
                  , dodgeProposition = "\"seed oils are not a significant, independent risk factor for public health.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/robmeijer.png"
          , cuckName = "Rob Meijer"
          , cuckSocial = "https://twitter.com/EngineerDiet"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1435850829051793408?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                ]
          }
        , { cuckImage = "cucks/robbwolf.png"
          , cuckName = "Robb Wolf"
          , cuckSocial = "https://twitter.com/robbwolf"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1601624559647875072?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = "\"ancestral foods are more likely to be antagonistically pleiotropic than novel foods.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/simongoddek.png"
          , cuckName = "Simon Goddek"
          , cuckSocial = "https://x.com/goddeketal"
          , cuckDodges =
                [ { dodgeLink = "https://x.com/TheNutrivore/status/1795673579931255233"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"vegetable oils increase the risk of heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1795885929678196951"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"vegetable oils increase the risk of heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://x.com/TheNutrivore/status/1795674575315112396"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"vegetable oils increase the risk of heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        , { cuckImage = "cucks/travisstatham.png"
          , cuckName = "Travis Statham"
          , cuckSocial = "https://twitter.com/Travis_Statham"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1461428023207489542?s=20"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils do not cause obesity.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                , { dodgeLink = "https://www.reddit.com/r/StopEatingSeedOils/comments/v457tu/how_vegetable_oils_make_us_fat_zero_acre/ic9u7wu/?utm_source=share"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"seed oils do not cause obesity.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/tristanhaggard.png"
          , cuckName = "Tristan Haggard"
          , cuckSocial = "https://twitter.com/Trxstxn4"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1513596227052527621?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"seed oils are toxic.\""
                  , dodgeNicksPosition = doxasticType.agnosticState
                  }
                ]
          }
        , { cuckImage = "cucks/trokalayjian.png"
          , cuckName = "Tro Kalayjian"
          , cuckSocial = "https://twitter.com/DoctorTro"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1261351818430255104?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"Dr. Tho engages in shitty behaviour that causes people to dislike him.\""
                  , dodgeNicksPosition = doxasticType.trueState
                  }
                ]
          }
        , { cuckImage = "cucks/tuckergoodrich.png"
          , cuckName = "Tucker Goodrich"
          , cuckSocial = "https://twitter.com/TuckerGoodrich"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1276694117494358017?s=19"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = "\"nutritional epidemiology is almost always wrong.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                , { dodgeLink = "https://twitter.com/TuckerGoodrich/status/1428062578668830720?s=20"
                  , dodgeDescription = dodgeType.ranAway
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                , { dodgeLink = "https://twitter.com/TuckerGoodrich/status/1469366622196359170?s=20"
                  , dodgeDescription = dodgeType.outrightNo
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                , { dodgeLink = "https://twitter.com/TuckerGoodrich/status/1470029816975872007?s=20"
                  , dodgeDescription = dodgeType.killScreen
                  , dodgeProposition = propType.noClearProp
                  , dodgeNicksPosition = doxasticType.unevalState
                  }
                ]
          }
        , { cuckImage = "cucks/zoeharcombe.png"
          , cuckName = "Zoe Harcombe"
          , cuckSocial = "https://twitter.com/zoeharcombe"
          , cuckDodges =
                [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1418263706178310149"
                  , dodgeDescription = dodgeType.noReply
                  , dodgeProposition = "\"saturated fat doesn't increase the risk of coronary heart disease.\""
                  , dodgeNicksPosition = doxasticType.falseState
                  }
                ]
          }
        ]
